==> nivo-0.15.0.tgz: package/es/components/charts/radar/Radar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import { max, isEqual, merge } from 'lodash-es';
import React from 'react';
import PropTypes from 'prop-types';
import { closedCurvePropType } from '../../../props';
import { withTheme, withColors, withCurve, withDimensions, withMotion } from '../../../hocs';
import SvgWrapper from '../SvgWrapper';
import { scaleLinear } from 'd3-scale';
import RadarShapes from './RadarShapes';
import RadarGrid from './RadarGrid';
import RadarMarkers from './RadarMarkers';
import compose from 'recompose/compose';
import pure from 'recompose/pure';
import withPropsOnChange from 'recompose/withPropsOnChange';
import defaultProps from 'recompose/defaultProps';

var Radar = function Radar(_ref) {
    var facets = _ref.facets,
        data = _ref.data,
        curveInterpolator = _ref.curveInterpolator,
        radius = _ref.radius,
        radiusScale = _ref.radiusScale,
        angleStep = _ref.angleStep,
        centerX = _ref.centerX,
        centerY = _ref.centerY,
        margin = _ref.margin,
        outerWidth = _ref.outerWidth,
        outerHeight = _ref.outerHeight,
        borderWidth = _ref.borderWidth,
        borderColor = _ref.borderColor,
        gridLevels = _ref.gridLevels,
        gridShape = _ref.gridShape,
        gridLabelOffset = _ref.gridLabelOffset,
        enableMarkers = _ref.enableMarkers,
        markersSize = _ref.markersSize,
        markersColor = _ref.markersColor,
        markersBorderWidth = _ref.markersBorderWidth,
        markersBorderColor = _ref.markersBorderColor,
        enableMarkersLabel = _ref.enableMarkersLabel,
        markersLabel = _ref.markersLabel,
        markersLabelFormat = _ref.markersLabelFormat,
        markersLabelYOffset = _ref.markersLabelYOffset,
        theme = _ref.theme,
        fillOpacity = _ref.fillOpacity,
        animate = _ref.animate,
        motionStiffness = _ref.motionStiffness,
        motionDamping = _ref.motionDamping,
        isInteractive = _ref.isInteractive;

    var motionProps = {
        animate: animate,
        motionDamping: motionDamping,
        motionStiffness: motionStiffness
    };

    return React.createElement(
        SvgWrapper,
        { width: outerWidth, height: outerHeight, margin: margin },
        React.createElement(
            'g',
            { transform: 'translate(' + centerX + ', ' + centerY + ')' },
            React.createElement(RadarGrid, _extends({
                levels: gridLevels,
                shape: gridShape,
                radius: radius,
                angleStep: angleStep,
                theme: theme,
                facets: facets,
                labelOffset: gridLabelOffset
            }, motionProps)),
            React.createElement(RadarShapes, _extends({
                data: data,
                radiusScale: radiusScale,
                angleStep: angleStep,
                curveInterpolator: curveInterpolator,
                borderWidth: borderWidth,
                borderColor: borderColor,
                fillOpacity: fillOpacity
            }, motionProps)),
            enableMarkers && React.createElement(RadarMarkers, _extends({
                facets: facets,
                data: data,
                radiusScale: radiusScale,
                angleStep: angleStep,
                size: markersSize,
                color: markersColor,
                borderWidth: markersBorderWidth,
                borderColor: markersBorderColor,
                enableLabel: enableMarkersLabel,
                label: markersLabel,
                labelFormat: markersLabelFormat,
                labelYOffset: markersLabelYOffset,
                theme: theme
            }, motionProps))
        )
    );
};

Radar.propTypes = {
    // data
    facets: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])).isRequired,
    data: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string.isRequired,
        data: PropTypes.arrayOf(PropTypes.number).isRequired
    })).isRequired,

    curve: closedCurvePropType.isRequired,
    curveInterpolator: PropTypes.func.isRequired,

    // border
    borderWidth: PropTypes.number.isRequired,
    borderColor: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),

    // grid
    gridLevels: PropTypes.number,
    gridShape: PropTypes.oneOf(['circular', 'linear']),
    gridLabelOffset: PropTypes.number,

    // markers
    enableMarkers: PropTypes.bool.isRequired,
    markersSize: PropTypes.number,
    markersColor: PropTypes.any,
    markersBorderWidth: PropTypes.number,
    markersBorderColor: PropTypes.any,
    enableMarkersLabel: PropTypes.bool,
    markersLabel: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
    markersLabelFormat: PropTypes.string,
    markersLabelYOffset: PropTypes.number,

    // theming
    getColor: PropTypes.func.isRequired,
    fillOpacity: PropTypes.number.isRequired,

    isInteractive: PropTypes.bool.isRequired
};

export var RadarDefaultProps = {
    curve: 'linearClosed',

    // border
    borderWidth: 2,
    borderColor: 'inherit',

    // grid
    gridLevels: 5,
    gridShape: 'circular',
    gridLabelOffset: 16,

    // markers
    enableMarkers: true,

    // theming
    fillOpacity: 0.15,

    // interactivity
    isInteractive: true
};

var enhance = compose(defaultProps(RadarDefaultProps), withTheme(), withColors(), withCurve(), withDimensions(), withMotion(), withPropsOnChange(function (props, nextProps) {
    return props.facets !== nextProps.facets || props.data !== nextProps.data || props.width !== nextProps.width || props.height !== nextProps.height || props.getColor !== nextProps.getColor;
}, function (_ref2) {
    var facets = _ref2.facets,
        data = _ref2.data,
        getColor = _ref2.getColor,
        width = _ref2.width,
        height = _ref2.height;

    var maxValue = max(data.reduce(function (acc, serie) {
        return [].concat(acc, serie.data);
    }, []));

    var radius = Math.min(width, height) / 2;
    var radiusScale = scaleLinear().range([0, radius]).domain([0, maxValue]);

    return {
        data: data.map(function (d) {
            return Object.assign({}, d, { color: getColor(d) });
        }),
        radius: radius,
        radiusScale: radiusScale,
        centerX: width / 2,
        centerY: height / 2,
        angleStep: Math.PI * 2 / facets.length
    };
}), pure);

export default enhance(Radar);

==> nivo-0.17.0.tgz: package/es/components/charts/radar/Radar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import { max, isEqual, merge } from 'lodash-es';
import React from 'react';
import PropTypes from 'prop-types';
import compose from 'recompose/compose';
import pure from 'recompose/pure';
import withPropsOnChange from 'recompose/withPropsOnChange';
import defaultProps from 'recompose/defaultProps';
import { closedCurvePropType } from '../../../props';
import { withTheme, withColors, withCurve, withDimensions, withMotion } from '../../../hocs';
import SvgWrapper from '../SvgWrapper';
import { scaleLinear } from 'd3-scale';
import RadarShapes from './RadarShapes';
import RadarGrid from './RadarGrid';
import RadarMarkers from './RadarMarkers';
import { getAccessorFor } from '../../../lib/propertiesConverters';

var Radar = function Radar(_ref) {
    var data = _ref.data,
        keys = _ref.keys,
        getIndex = _ref.getIndex,
        indices = _ref.indices,
        curveInterpolator = _ref.curveInterpolator,
        radius = _ref.radius,
        radiusScale = _ref.radiusScale,
        angleStep = _ref.angleStep,
        centerX = _ref.centerX,
        centerY = _ref.centerY,
        margin = _ref.margin,
        outerWidth = _ref.outerWidth,
        outerHeight = _ref.outerHeight,
        borderWidth = _ref.borderWidth,
        borderColor = _ref.borderColor,
        gridLevels = _ref.gridLevels,
        gridShape = _ref.gridShape,
        gridLabelOffset = _ref.gridLabelOffset,
        enableMarkers = _ref.enableMarkers,
        markersSize = _ref.markersSize,
        markersColor = _ref.markersColor,
        markersBorderWidth = _ref.markersBorderWidth,
        markersBorderColor = _ref.markersBorderColor,
        enableMarkersLabel = _ref.enableMarkersLabel,
        markersLabel = _ref.markersLabel,
        markersLabelFormat = _ref.markersLabelFormat,
        markersLabelYOffset = _ref.markersLabelYOffset,
        theme = _ref.theme,
        fillOpacity = _ref.fillOpacity,
        colorByKey = _ref.colorByKey,
        animate = _ref.animate,
        motionStiffness = _ref.motionStiffness,
        motionDamping = _ref.motionDamping,
        isInteractive = _ref.isInteractive;

    var motionProps = {
        animate: animate,
        motionDamping: motionDamping,
        motionStiffness: motionStiffness
    };

    return React.createElement(
        SvgWrapper,
        { width: outerWidth, height: outerHeight, margin: margin },
        React.createElement(
            'g',
            { transform: 'translate(' + centerX + ', ' + centerY + ')' },
            React.createElement(RadarGrid, _extends({
                levels: gridLevels,
                shape: gridShape,
                radius: radius,
                angleStep: angleStep,
                theme: theme,
                indices: indices,
                labelOffset: gridLabelOffset
            }, motionProps)),
            React.createElement(RadarShapes, _extends({
                data: data,
                keys: keys,
                colorByKey: colorByKey,
                radiusScale: radiusScale,
                angleStep: angleStep,
                curveInterpolator: curveInterpolator,
                borderWidth: borderWidth,
                borderColor: borderColor,
                fillOpacity: fillOpacity
            }, motionProps)),
            enableMarkers && React.createElement(RadarMarkers, _extends({
                data: data,
                keys: keys,
                getIndex: getIndex,
                radiusScale: radiusScale,
                angleStep: angleStep,
                size: markersSize,
                colorByKey: colorByKey,
                color: markersColor,
                borderWidth: markersBorderWidth,
                borderColor: markersBorderColor,
                enableLabel: enableMarkersLabel,
                label: markersLabel,
                labelFormat: markersLabelFormat,
                labelYOffset: markersLabelYOffset,
                theme: theme
            }, motionProps))
        )
    );
};

Radar.propTypes = {
    // data
    data: PropTypes.arrayOf(PropTypes.object).isRequired,
    keys: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])).isRequired,
    indexBy: PropTypes.oneOfType([PropTypes.number, PropTypes.string, PropTypes.func]).isRequired,
    getIndex: PropTypes.func.isRequired, // computed
    indices: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])).isRequired, // computed

    curve: closedCurvePropType.isRequired,
    curveInterpolator: PropTypes.func.isRequired, // computed

    // border
    borderWidth: PropTypes.number.isRequired,
    borderColor: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),

    // grid
    gridLevels: PropTypes.number,
    gridShape: PropTypes.oneOf(['circular', 'linear']),
    gridLabelOffset: PropTypes.number,

    // markers
    enableMarkers: PropTypes.bool.isRequired,
    markersSize: PropTypes.number,
    markersColor: PropTypes.any,
    markersBorderWidth: PropTypes.number,
    markersBorderColor: PropTypes.any,
    enableMarkersLabel: PropTypes.bool,
    markersLabel: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
    markersLabelFormat: PropTypes.string,
    markersLabelYOffset: PropTypes.number,

    // theming
    getColor: PropTypes.func.isRequired, // computed
    colorByKey: PropTypes.object.isRequired, // computed
    fillOpacity: PropTypes.number.isRequired,

    // interactivity
    isInteractive: PropTypes.bool.isRequired
};

export var RadarDefaultProps = {
    curve: 'linearClosed',

    // border
    borderWidth: 2,
    borderColor: 'inherit',

    // grid
    gridLevels: 5,
    gridShape: 'circular',
    gridLabelOffset: 16,

    // markers
    enableMarkers: true,

    // theming
    fillOpacity: 0.15,

    // interactivity
    isInteractive: true
};

var enhance = compose(defaultProps(RadarDefaultProps), withTheme(), withColors({
    defaultColorBy: 'key'
}), withCurve(), withDimensions(), withMotion(), withPropsOnChange(['indexBy'], function (_ref2) {
    var indexBy = _ref2.indexBy;
    return {
        getIndex: getAccessorFor(indexBy)
    };
}), withPropsOnChange(['data', 'getIndex'], function (_ref3) {
    var data = _ref3.data,
        getIndex = _ref3.getIndex;
    return {
        indices: data.map(getIndex)
    };
}), withPropsOnChange(['keys', 'getColor'], function (_ref4) {
    var keys = _ref4.keys,
        getColor = _ref4.getColor;
    return {
        colorByKey: keys.reduce(function (mapping, key, index) {
            mapping[key] = getColor({ key: key, index: index });
            return mapping;
        }, {})
    };
}), withPropsOnChange(function (props, nextProps) {
    return props.keys !== nextProps.keys || props.indexBy !== nextProps.indexBy || props.data !== nextProps.data || props.width !== nextProps.width || props.height !== nextProps.height;
}, function (_ref5) {
    var data = _ref5.data,
        keys = _ref5.keys,
        width = _ref5.width,
        height = _ref5.height;

    var maxValue = max(data.reduce(function (acc, d) {
        return [].concat(acc, keys.map(function (key) {
            return d[key];
        }));
    }, []));

    var radius = Math.min(width, height) / 2;
    var radiusScale = scaleLinear().range([0, radius]).domain([0, maxValue]);

    return {
        data: data,
        radius: radius,
        radiusScale: radiusScale,
        centerX: width / 2,
        centerY: height / 2,
        angleStep: Math.PI * 2 / data.length
    };
}), pure);

export default enhance(Radar);
